#
# spec file for package rnp
#
# Copyright (c) 2024 Andreas Stieger <Andreas.Stieger@gmx.de>
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define soname 0
Name:           rnp
Version:        0.17.1
Release:        3.5
Summary:        OpenPGP implementation fully compliant with RFC 4880
License:        Apache-2.0 AND BSD-2-Clause AND BSD-3-Clause
URL:            https://www.rnpgp.com/
Source:         https://github.com/rnpgp/rnp/releases/download/v%{version}/%{name}-v%{version}.tar.gz
Source2:        https://github.com/rnpgp/rnp/releases/download/v%{version}/%{name}-v%{version}.tar.gz.asc
Source3:        https://www.rnpgp.org/openpgp_keys/31AF5A24D861EFCB7CB79A1924900CE0AEFB5417-50DA59D5B9134FA2DB1EB20CFB829AB5D0FE017F.asc#/%{name}.keyring
BuildRequires:  c++_compiler
BuildRequires:  cmake >= 3.18
BuildRequires:  gpg2 >= 2.2
BuildRequires:  gtest
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(bzip2)
BuildRequires:  pkgconfig(json-c) >= 0.11
BuildRequires:  pkgconfig(sexpp) >= 0.8.7
BuildRequires:  pkgconfig(zlib)
BuildRequires:  rubygem(asciidoctor)
%if (0%{?suse_version} > 1600) || (0%{?sle_version} >= 150700 && 0%{?is_opensuse})
BuildRequires:  pkgconfig(botan-3) >= 3.0.0
%else
BuildRequires:  pkgconfig(botan-2) >= 2.14.0
%endif
%if 0%{?sle_version} >= 150700 && 0%{?is_opensuse}
BuildRequires:  gcc12-c++
%endif

%description
RNP is a set of OpenPGP (RFC4880) tools, an alternative to GnuPG.

%package -n librnp%{soname}
Summary:        OpenPGP implementation as a C++ library fully compliant with RFC 4880

%description -n librnp%{soname}
RNP is a set of OpenPGP (RFC4880) tools, an alternative to GnuPG.
librnp is the library used by RNP for all OpenPGP functions, useful for
developers to build against, different from GPGME.

%package devel
Summary:        Development files for RNP
Requires:       librnp%{soname} = %{version}

%description devel
RNP is a set of OpenPGP (RFC4880) tools, an alternative to GnuPG.
This package contains the files needed to build against librnp.

%prep
%autosetup -p1 -n %{name}-v%{version}
rm -rf src/libsexp

%build
%if 0%{?sle_version} >= 150700 && 0%{?is_opensuse}
export CC=gcc-12
export CXX=g++-12
%endif
%cmake \
	-DDOWNLOAD_GTEST:BOOL=OFF \
	-DBUILD_TESTING:BOOL=ON \
	-DSYSTEM_LIBSEXPP:BOOL=ON \
	%{nil}
%cmake_build

%install
%cmake_install

%check
%ctest

%ldconfig_scriptlets -n librnp%{soname}

%files
%license LICENSE*
%{_bindir}/*
%{_mandir}/man1/*.1%{?ext_man}

%files -n librnp%{soname}
%license LICENSE*
%{_libdir}/*.so.0*

%files devel
%license LICENSE*
%doc CHANGELOG.md README.adoc
%{_includedir}/*
%{_libdir}/cmake/rnp
%{_libdir}/*.so
%{_libdir}/pkgconfig/*.pc
%{_mandir}/man3/*.3%{?ext_man}

%changelog
* Sat Aug 17 2024 Andreas Stieger <andreas.stieger@gmx.de>
- Build with Botan 3 on Leap 15.7
* Tue Jul 30 2024 Andreas Stieger <andreas.stieger@gmx.de>
- Build with Botan 3 on Tumbleweed
* Sun Jul 28 2024 Andreas Stieger <andreas.stieger@gmx.de>
- rnp 0.17.1:
  * Added support for Botan 3
  * Updated support for OpenSSL 3
  * Added support for mimemode in literal data packet
  * Relaxed Base64 decoding to allow spaces after the checksum
  * Added functions rnp_key_set_features() and
    rnp_signature_get_features()
- drop patches no longer needed:
  * rnp-v0.17.0-cpp14-googletest.patch
  * rnp-v0.17.0-disable-static.patch
  * rnp-v0.17.0-system-sexp.patch
  * rnp-v0.17.0-test-SHA1-cutoff.patch
  * rnp-v0.17.0-tests.patch
* Wed Apr  3 2024 Andreas Stieger <andreas.stieger@gmx.de>
- switch to C++14 to fix build with new GoogleTest 1.14.0
  add rnp-v0.17.0-cpp14-googletest.patch
* Sat Jan 20 2024 Andreas Stieger <andreas.stieger@gmx.de>
- fix build after SHA-1 cutoff date
  add rnp-v0.17.0-test-SHA1-cutoff.patch
* Mon Jun 26 2023 Andreas Stieger <Andreas.Stieger@gmx.de>
- build with system sexpp library (renamed)
* Mon Jun 19 2023 Andreas Stieger <Andreas.Stieger@gmx.de>
- fix s390x tests - add rnp-v0.17.0-tests.patch
* Wed Jun 14 2023 Andreas Stieger <Andreas.Stieger@gmx.de>
- build with system sexp library
  (add rnp-v0.17.0-system-sexp.patch)
- drop rnp-v0.17.0-gcc13.patch no longer needed
* Wed Jun 14 2023 Andreas Stieger <Andreas.Stieger@gmx.de>
- fix build on Leap (json-c)
* Mon Jun 12 2023 Andreas Stieger <Andreas.Stieger@gmx.de>
- rnp 0.17.0:
  * Add support for hidden recipient during decryption
  * Improve support for offline secret keys during default key
    selection
  * Support for GnuPG 2
  * SExp parsing code is moved to separate library
  * Mark subkeys as expired instead of invalid if primary key is
    expired
  * AEAD: use OCB by default instead of EAX
  * Do not attempt to validate signatures of unexpected types
  * Use thread-safe time and date handling functions
  * Added ENABLE_BLOWFISH, ENABLE_CAST5 and ENABLE_RIPEMD160 build
    time options
  * Corrected usage of CEK/KEK algorithms if those differs
  * Add default armor message type for --enarmor command
  * Add command --set-filename to specify which file name should be stored in message
  * Add --add-subkey subcommand to the --edit-key
  * Add set-expire subcommand to the --edit-key
  * Add --s2k-iterations and --s2k-msec options to the rnp
  * dd --allow-weak-hash command to allow usage of weak hash algorithms
  * Report number of new/updated keys during the key import
- add rnp-v0.17.0-disable-static.patch
- add rnp-v0.17.0-gcc13.patch
- uses bundled libsexp
* Mon Jun 12 2023 Andreas Stieger <andreas.stieger@gmx.de>
- rnp 0.16.3:
  * CVE-2023-29479: Fix issue with possible hang on malformed
    inputs (boo#1212253)
  * CVE-2023-29480: Fix issue where in some cases, secret keys
    remain unlocked after use (boo#1212254)
* Mon Sep 26 2022 Andreas Stieger <andreas.stieger@gmx.de>
- rnp 0.16.2:
  * Support a number of additional key and encryption operations
  * Now uses separate security rules for the data and key signatures,
    extending SHA1 key signature support till the Jan, 19 2024.
  * The default key expiration time was set to 2 years.
  * The library got a number of developer visible updates,
    and the command-line interface gained a number of additional
    knobs, switches, and output improvements
* Sun May 22 2022 Andreas Stieger <andreas.stieger@gmx.de>
- add upstream signing key and verify source signature
* Sun Feb 13 2022 Andreas Stieger <andreas.stieger@gmx.de>
- rnp 0.16.0:
  * Ability to disable certain features via compile-time switches
    (ENABLE_AEAD, ENABLE_SM2, etc.)
  * Mark signatures with SHA1/MD5 hash, produced after the specific
    date (2019-01-19 and 2012-01-01) as invalid
  * Fixed possible incompatibility with GnuPG on x25519 secret key
    export
  * Fixed export of non-FFI symbols from rnp.so/rnp.dylib
  * Fixed key expiration time calculation in some edge cases
  * Added security profile manipulation functions to the FFI
  * Improved CLI tools help messages
  * Improved CLI: stdin/stdout/env input/output specifiers, --notty
    for batch processing, etc.
* Sat Jan 15 2022 Andreas Stieger <andreas.stieger@gmx.de>
- disable tests
* Mon Aug  9 2021 Andreas Stieger <andreas.stieger@gmx.de>
- rnp 0.15.2:
  * Be less strict in userid validation: allow to use userids with
    self-signature, which has key expiration in the past
  * Do not mark signature as invalid if key which produced it is
    expired now, but was valid during signing
  * Fix incorrect key expiration calculation in some cases
  * rnp: Show error message if encryption failed
  * rnpkeys: Add --expiration option to specify expiration time
    during key generation
- run tests
* Mon Jun 28 2021 Andreas Stieger <andreas.stieger@gmx.de>
- rnp 0.15.1:
  * Fix updating of expiration time for a key with multiple user
    IDs
  * Fixed key expiry check for keys valid after the year 2038
  * Pick up key expiration time from direct-key signature or primary
    userid certification if available
  * CVE-2021-33589: issue with cleartext key data after the
    rnp_key_unprotect()/rnp_key_protect() calls (boo#1187759)
- includes changes from 0.15.0:
  * Improve handling of cleartext signatures, when empty line
    between headers and contents contains some whitespace
  * Relax requirements for the armored messages CRC (allow absence
    of the CRC, and issue warning instead of complete failure)
  * documentation updates
  * rnpkeys: add --remove-key command
* Sun Feb 21 2021 Andreas Stieger <andreas.stieger@gmx.de>
- initial package, 0.14.0
